@@ -22,42 +22,47 @@ import re
 
 from .hyper_parser import HyperParser
 from .autocomplete_window import AutocompleteWindow, find_prefix_range
-from .beep import beep
+from .common import beep, get_text
 
 # This string includes all chars that may be in an identifier
 ID_CHARS = string.ascii_letters + string.digits + "_"
 ID_CHARS_DOT = ID_CHARS + '.'
 
 class Autocomplete(object):
-    def __init__(self, sourceview, 
+    def __init__(self, sourceview, sv_changed, window_main,
                  complete_attributes, complete_firstlevels, get_func_args,
                  find_modules, get_module_members, complete_filenames,
+                 complete_dict_keys,
                  INDENT_WIDTH):
         self.sourceview = sourceview
-        self.sourcebuffer = sourceview.get_buffer()
+        sv_changed.append(self._on_sv_changed)
         self.complete_attributes = complete_attributes
         self.complete_firstlevels = complete_firstlevels
         self.get_func_args = get_func_args
         self.find_modules = find_modules
         self.get_module_members = get_module_members
         self.complete_filenames = complete_filenames
+        self.complete_dict_keys = complete_dict_keys
         self.INDENT_WIDTH = INDENT_WIDTH
 
-        self.window = AutocompleteWindow(sourceview, self._on_complete)
+        self.window = AutocompleteWindow(sourceview, sv_changed, window_main,
+                                         self._on_complete)
 
+    def _on_sv_changed(self, new_sv):
+        self.sourceview = new_sv
+    
     def show_completions(self, is_auto, complete):
         """
-        If complete is False, just show the comopletion list.
+        If complete is False, just show the completion list.
         If complete is True, complete as far as possible. If there's only
         one completion, don't show the window.
 
         If is_auto is True, don't beep if can't find completions.
         """
-        sb = self.sourcebuffer
-        text = sb.get_slice(sb.get_start_iter(),
-                            sb.get_end_iter()).decode('utf8')
+        sb = self.sourceview.get_buffer()
+        text = get_text(sb, sb.get_start_iter(), sb.get_end_iter())
         index = sb.get_iter_at_mark(sb.get_insert()).get_offset()
-        hp = HyperParser(text, index, self.INDENT_WIDTH)
+        hp = HyperParser(text[:index], index, self.INDENT_WIDTH)
 
         if hp.is_in_code():
             line = text[text.rfind('\n', 0, index)+1:index].lstrip()
@@ -71,10 +76,17 @@ class Autocomplete(object):
                     res = self._complete_modules(line, is_auto)
                 else:
                     res = self._complete_module_members(line, is_auto)
+            elif line.endswith('['):
+                # We complete dict keys either after a '[' or in a string
+                # after a '['.
+                res = self._complete_dict_keys(text, index, hp, is_auto)
             else:
                 res = self._complete_attributes(text, index, hp, is_auto)
         elif hp.is_in_string():
-            res = self._complete_filenames(text, index, hp, is_auto)
+            if text[max(hp.bracketing[hp.indexbracket][0]-1,0)] == '[':
+                res = self._complete_dict_keys(text, index, hp, is_auto)
+            else:
+                res = self._complete_filenames(text, index, hp, is_auto)
         else:
             # Not in string and not in code
             res = None
@@ -112,11 +124,50 @@ class Autocomplete(object):
                 sb.insert_at_cursor(combined[start][len(comp_prefix):i])
                 comp_prefix = first[:i]
             if end == start + 1:
-                # Only one matchine completion - don't show the window
+                # Only one matching completion - don't show the window
+                self._on_complete()
                 return
 
         self.window.show(public, private, is_case_insen, len(comp_prefix))
         
+    def _complete_dict_keys(self, text, index, hp, is_auto):
+        """
+        Return (comp_prefix, public, private, is_case_insen) 
+        (string, list, list, bool).
+        If shouldn't complete - return None.
+        """
+        # Check whether auto-completion is really appropriate,
+        if is_auto and text[index-1] != '[':
+            return
+        
+        is_in_code = hp.is_in_code()
+        opener, _closer = hp.get_surrounding_brackets('[')
+        if opener is None:
+            return
+        hp.set_index(opener)
+        comp_what = hp.get_expression()
+        if not comp_what:
+            # It's not an index, but a list - complete as if the '[' wasn't there.
+            hp.set_index(index)
+            if is_in_code:
+                return self._complete_attributes(text, index, hp, is_auto)
+            else:
+                return self._complete_filenames(text, index, hp, is_auto)
+        if is_auto and '(' in comp_what:
+            # Don't evaluate expressions which may contain a function call.
+            return
+        key_reprs = self.complete_dict_keys(comp_what)
+        if key_reprs is None:
+            return
+        if text[index:index+1] != ']':
+            key_reprs = [x+']' for x in key_reprs]
+
+        comp_prefix = text[opener+1:index]
+        public = key_reprs
+        private = []
+        is_case_insen = False
+        return (comp_prefix, public, private, is_case_insen)
+
     def _complete_attributes(self, text, index, hp, is_auto):
         """
         Return (comp_prefix, public, private, is_case_insen) 
