@@ -19,7 +19,7 @@ __all__ = ['Config']
 
 import sys
 import os
-from ConfigParser import SafeConfigParser
+from ConfigParser import RawConfigParser
 from StringIO import StringIO
 
 from .odict import OrderedDict
@@ -41,6 +41,7 @@ viewer = ''
 init-code = ''
 autoparen = True
 expects-str-2 = execfile chdir open run runeval
+vertical-layout = True
 ask-on-quit = True
 matplotlib-ia-switch = False
 matplotlib-ia-warn = True
@@ -87,6 +88,14 @@ comment-bg = black
 
 bracket-match-fg = white
 bracket-match-bg = darkblue
+bracket-1-fg = #abffab
+bracket-1-bg = black
+bracket-2-fg = #dfabff
+bracket-2-bg = black
+bracket-3-fg = #ffabab
+bracket-3-bg = black
+error-fg = white
+error-bg = red
 
 stdin-fg-set = False
 stdin-bg-set = False
@@ -120,6 +129,14 @@ comment-bg-set = False
 
 bracket-match-fg-set = False
 bracket-match-bg-set = True
+bracket-1-fg-set = True
+bracket-1-bg-set = False
+bracket-2-fg-set = True
+bracket-2-bg-set = False
+bracket-3-fg-set = True
+bracket-3-bg-set = False
+error-fg-set = False
+error-bg-set = True
 
 [Light theme]
 is-active = True
@@ -159,6 +176,14 @@ comment-bg = white
 
 bracket-match-fg = black
 bracket-match-bg = lightblue
+bracket-1-fg = #005400
+bracket-1-bg = white
+bracket-2-fg = #9400f0
+bracket-2-bg = white
+bracket-3-fg = brown
+bracket-3-bg = #a50000
+error-fg = black
+error-bg = red
 
 stdin-fg-set = False
 stdin-bg-set = False
@@ -192,6 +217,14 @@ comment-bg-set = False
 
 bracket-match-fg-set = False
 bracket-match-bg-set = True
+bracket-1-fg-set = True
+bracket-1-bg-set = False
+bracket-2-fg-set = True
+bracket-2-bg-set = False
+bracket-3-fg-set = True
+bracket-3-bg-set = False
+error-fg-set = False
+error-bg-set = True
 
 """
 
@@ -211,17 +244,17 @@ def get_config_fn():
 
 class Config(object):
     """
-    Manage configuration - a simple wrapper around SafeConfigParser.
+    Manage configuration - a simple wrapper around RawConfigParser.
     Upon initialization, the loaded file is updated with the default values.
     config.save() will save the current state.
     """
     def __init__(self):
         self.filename = get_config_fn()
         try:
-            self.parser = SafeConfigParser(dict_type=OrderedDict)
+            self.parser = RawConfigParser(dict_type=OrderedDict)
         except TypeError:
             # Python versions < 2.6 don't support dict_type
-            self.parser = SafeConfigParser()
+            self.parser = RawConfigParser()
         f = StringIO(default_config)
         self.parser.readfp(f)
         self.parser.read(self.filename)
