@@ -28,7 +28,7 @@ import pango
 from .SimpleGladeApp import SimpleGladeApp
 from . import tags
 from .tags import DEFAULT, FG, BG, COLOR, ISSET
-from .beep import beep
+from .common import beep, get_text
 from .file_dialogs import open_dialog
 
 # Allow future translations
@@ -61,6 +61,9 @@ class ConfigDialog(SimpleGladeApp):
         self.autoparen_chk.props.active = config.get_bool('autoparen')
         self.expects_str_entry.props.text = config.get('expects-str-2')
         
+        self.vertical_layout_rad.props.active = config.get_bool('vertical-layout')
+        self.horizontal_layout_rad.props.active = not config.get_bool('vertical-layout')
+        
         self.leave_code_chk.props.active = config.get_bool('leave-code')
         
         self.hide_defs_chk.props.active = config.get_bool('hide-defs')
@@ -149,6 +152,8 @@ class ConfigDialog(SimpleGladeApp):
         config.set_bool('autoparen', self.autoparen_chk.props.active)
         config.set('expects-str-2', expects_str)
         
+        config.set_bool('vertical-layout', self.vertical_layout_rad.props.active)
+        
         config.set_bool('leave-code', self.leave_code_chk.props.active)
         
         config.set_bool('hide-defs', self.hide_defs_chk.props.active)
@@ -167,8 +172,7 @@ class ConfigDialog(SimpleGladeApp):
         config.set_bool('ask-on-quit', self.ask_on_quit_chk.props.active)
         
         sb = self.sourcebuffer
-        init_code = sb.get_text(sb.get_start_iter(),
-                                sb.get_end_iter()).decode('utf8')
+        init_code = get_text(sb, sb.get_start_iter(), sb.get_end_iter())
         config.set('init-code', repr(init_code))
         
         tags.remove_themes(config)
